@@ -15,15 +15,18 @@ import time
 #import core_helper.helper_plot as  hp
 from data_science_helper import helper_plot as hp
 
-def get_neg_bagging_fraction_params(y_train,params):
+def get_neg_bagging_fraction_params(y_train=None,params=None,log=0):
     
     N_p = y_train[y_train==1].count()
     N_n = y_train[y_train==0].count()
     #T_minimo= 43000
     T_minimo = get_Total_min_to_train(N_p)
-    print("T_minimo : ",T_minimo)
-    print("N_p : ",N_p)
-    print("N_n : ",N_n)
+    
+    if  log is not None and log>0 :
+    
+        print("T_minimo : ",T_minimo)
+        print("N_p : ",N_p)
+        print("N_n : ",N_n)
     
     alpha = (T_minimo-N_p)/N_n
     if params is None:
