@@ -68,10 +68,10 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     list_TN_train = []
     list_FN_train = []
     
-    list_TP_train_opt = []
-    list_FP_train_opt = []
-    list_TN_train_opt = []
-    list_FN_train_opt = []
+    #list_TP_train_opt = []
+    #list_FP_train_opt = []
+    #list_TN_train_opt = []
+    #list_FN_train_opt = []
     
     list_valid_precision = []
     list_valid_recall = []
@@ -84,13 +84,13 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     list_TN_valid = []
     list_FN_valid = []
     
-    list_TP_valid_opt = []
-    list_FP_valid_opt = []
-    list_TN_valid_opt = []
-    list_FN_valid_opt = []
+    #list_TP_valid_opt = []
+    #list_FP_valid_opt = []
+    #list_TN_valid_opt = []
+    #list_FN_valid_opt = []
     
-    list_opt_threshold_train = []
-    list_opt_threshold_valid = []
+    #list_opt_threshold_train = []
+    #list_opt_threshold_valid = []
     
     with_bias = False
     
@@ -125,12 +125,12 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         list_TN_train.append(kpi["train/TN"])  
         list_FN_train.append(kpi["train/FN"])  
         
-        list_opt_threshold_train.append(kpi["train/opt_threshold_train"]) 
+        #list_opt_threshold_train.append(kpi["train/opt_threshold_train"]) 
         
-        list_TP_train_opt.append(kpi["train/TP_opt"])    
-        list_FP_train_opt.append(kpi["train/FP_opt"])  
-        list_TN_train_opt.append(kpi["train/TN_opt"])  
-        list_FN_train_opt.append(kpi["train/FN_opt"]) 
+        #list_TP_train_opt.append(kpi["train/TP_opt"])    
+        #list_FP_train_opt.append(kpi["train/FP_opt"])  
+        #list_TN_train_opt.append(kpi["train/TN_opt"])  
+        #list_FN_train_opt.append(kpi["train/FN_opt"]) 
 
         list_valid_score.append(kpi["valid/average_precision"])
         
@@ -145,12 +145,12 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         list_TN_valid.append(kpi["valid/TN"])  
         list_FN_valid.append(kpi["valid/FN"])  
         
-        list_opt_threshold_valid.append(kpi["valid/opt_threshold_valid"]) 
+        #list_opt_threshold_valid.append(kpi["valid/opt_threshold_valid"]) 
         
-        list_TP_valid_opt.append(kpi["valid/TP_opt"])    
-        list_FP_valid_opt.append(kpi["valid/FP_opt"])  
-        list_TN_valid_opt.append(kpi["valid/TN_opt"])  
-        list_FN_valid_opt.append(kpi["valid/FN_opt"])  
+        #list_TP_valid_opt.append(kpi["valid/TP_opt"])    
+        #list_FP_valid_opt.append(kpi["valid/FP_opt"])  
+        #list_TN_valid_opt.append(kpi["valid/TN_opt"])  
+        #list_FN_valid_opt.append(kpi["valid/FN_opt"])  
         
         bias = kpi["bias"]
         
@@ -162,11 +162,11 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
             break
         
     
-    mean_train_opt_threshold = statistics.mean(list_opt_threshold_train)
-    std_train_opt_threshold = statistics.pstdev(list_opt_threshold_train)
+    #mean_train_opt_threshold = statistics.mean(list_opt_threshold_train)
+    #std_train_opt_threshold = statistics.pstdev(list_opt_threshold_train)
     
-    mean_valid_opt_threshold = statistics.mean(list_opt_threshold_valid)
-    std_valid_opt_threshold = statistics.pstdev(list_opt_threshold_valid)
+    #mean_valid_opt_threshold = statistics.mean(list_opt_threshold_valid)
+    #std_valid_opt_threshold = statistics.pstdev(list_opt_threshold_valid)
     
         
     mean_train_score = statistics.mean(list_train_score)
@@ -196,7 +196,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     
     
     
-    
+    ''' 
     mean_TP_train_opt = statistics.mean(list_TP_train_opt)
     std_TP_train_opt = statistics.pstdev(list_TP_train_opt)
     mean_FP_train_opt = statistics.mean(list_FP_train_opt)
@@ -214,7 +214,7 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
     std_TN_valid_opt = statistics.pstdev(list_TN_valid_opt)
     mean_FN_valid_opt = statistics.mean(list_FN_valid_opt)
     std_FN_valid_opt = statistics.pstdev(list_FN_valid_opt)
-    
+    '''
     
 
     mean_train_precision = statistics.mean(list_train_precision)           
@@ -307,18 +307,18 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         
 
         
-        'mean_train_opt_threshold':mean_train_opt_threshold   ,
-        'std_train_opt_threshold':std_train_opt_threshold   ,
+        #'mean_train_opt_threshold':mean_train_opt_threshold   ,
+        #'std_train_opt_threshold':std_train_opt_threshold   ,
         
         
-        'mean_TP_train_opt':mean_TP_train_opt   ,
-        'std_TP_train_opt':std_TP_train_opt   ,
-        'mean_FP_train_opt':mean_FP_train_opt   ,
-        'std_FP_train_opt':std_FP_train_opt   ,
-        'mean_TN_train_opt':mean_TN_train_opt   ,
-        'std_TN_train_opt':std_TN_train_opt   ,
-        'mean_FN_train_opt':mean_FN_train_opt   ,
-        'std_FN_train_opt':std_FN_train_opt   ,
+        #'mean_TP_train_opt':mean_TP_train_opt   ,
+        #'std_TP_train_opt':std_TP_train_opt   ,
+        #'mean_FP_train_opt':mean_FP_train_opt   ,
+        #'std_FP_train_opt':std_FP_train_opt   ,
+        #'mean_TN_train_opt':mean_TN_train_opt   ,
+        #'std_TN_train_opt':std_TN_train_opt   ,
+        #'mean_FN_train_opt':mean_FN_train_opt   ,
+        #'std_FN_train_opt':std_FN_train_opt   ,
         
         
         'mean_valid_precision':mean_valid_precision,
@@ -341,18 +341,18 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         'mean_FN_valid':mean_FN_valid   ,
         'std_FN_valid':std_FN_valid   ,
         
-        'mean_valid_opt_threshold':mean_valid_opt_threshold   ,
-        'std_valid_opt_threshold':std_valid_opt_threshold   ,
+        #'mean_valid_opt_threshold':mean_valid_opt_threshold   ,
+        #'std_valid_opt_threshold':std_valid_opt_threshold   ,
         
         
-        'mean_TP_valid_opt':mean_TP_valid_opt   ,
-        'std_TP_valid_opt':std_TP_valid_opt   ,
-        'mean_FP_valid_opt':mean_FP_valid_opt   ,
-        'std_FP_valid_opt':std_FP_valid_opt   ,
-        'mean_TN_valid_opt':mean_TN_valid_opt   ,
-        'std_TN_valid_opt':std_TN_valid_opt   ,
-        'mean_FN_valid_opt':mean_FN_valid_opt   ,
-        'std_FN_valid_opt':std_FN_valid_opt   ,        
+        #'mean_TP_valid_opt':mean_TP_valid_opt   ,
+        #'std_TP_valid_opt':std_TP_valid_opt   ,
+        #'mean_FP_valid_opt':mean_FP_valid_opt   ,
+        #'std_FP_valid_opt':std_FP_valid_opt   ,
+        #'mean_TN_valid_opt':mean_TN_valid_opt   ,
+        #'std_TN_valid_opt':std_TN_valid_opt   ,
+        #'mean_FN_valid_opt':mean_FN_valid_opt   ,
+        #'std_FN_valid_opt':std_FN_valid_opt   ,        
         
         
     }
@@ -404,22 +404,22 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
     
     
     y_pred_train = np.rint(y_pred_prob_train)    
-    opt_threshold_train  = g.get_opt_threshold(y_train,y_pred_prob_train)
+    #opt_threshold_train  = g.get_opt_threshold(y_train,y_pred_prob_train)
     
     
     y_pred_valid = np.rint(y_pred_prob_valid)    
-    opt_threshold_valid  = g.get_opt_threshold(y_valid,y_pred_prob_valid)
-    print("11111111111111")
-    print(y_train.shape)
-    print("11111111111111")
+    #opt_threshold_valid  = g.get_opt_threshold(y_valid,y_pred_prob_valid)
+    #print("11111111111111")
+    #print(y_train.shape)
+    #print("11111111111111")
 
     TP_train, FP_train, TN_train, FN_train = perf_measure(y_train.values,y_pred_train)    
-    y_pred_train_opt = (y_pred_prob_train > opt_threshold_train).astype(int)
-    TP_train_opt, FP_train_opt, TN_train_opt, FN_train_opt = perf_measure(y_train.values,y_pred_train_opt)
+    #y_pred_train_opt = (y_pred_prob_train > opt_threshold_train).astype(int)
+    #TP_train_opt, FP_train_opt, TN_train_opt, FN_train_opt = perf_measure(y_train.values,y_pred_train_opt)
     
     TP_valid, FP_valid, TN_valid, FN_valid = perf_measure(y_valid.values,y_pred_valid)
-    y_pred_valid_opt = (y_pred_prob_valid > opt_threshold_valid).astype(int)
-    TP_valid_opt, FP_valid_opt, TN_valid_opt, FN_valid_opt = perf_measure(y_valid.values,y_pred_valid_opt)
+    #y_pred_valid_opt = (y_pred_prob_valid > opt_threshold_valid).astype(int)
+    #TP_valid_opt, FP_valid_opt, TN_valid_opt, FN_valid_opt = perf_measure(y_valid.values,y_pred_valid_opt)
 
     
     train_average_precision = average_precision_score(y_train, y_pred_prob_train)
@@ -445,13 +445,13 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
            'train/TN': TN_train,   
            'train/FN': FN_train,   
            
-           'train/opt_threshold_train': opt_threshold_train,  
+           #'train/opt_threshold_train': opt_threshold_train,  
            
            
-           'train/TP_opt': TP_train_opt,   
-           'train/FP_opt': FP_train_opt,   
-           'train/TN_opt': TN_train_opt,   
-           'train/FN_opt': FN_train_opt,  
+           #'train/TP_opt': TP_train_opt,   
+           #'train/FP_opt': FP_train_opt,   
+           #'train/TN_opt': TN_train_opt,   
+           #'train/FN_opt': FN_train_opt,  
            
            'valid/average_precision': valid_average_precision,
            'valid/precision': precision,
@@ -463,12 +463,12 @@ def fit_lgbm_with_pruning(trial=None, train=None, val=None, fn_params=None, cat_
            'valid/TN': TN_valid,   
            'valid/FN': FN_valid,   
            
-           'valid/TP_opt': TP_valid_opt,   
-           'valid/FP_opt': FP_valid_opt,   
-           'valid/TN_opt': TN_valid_opt,   
-           'valid/FN_opt': FN_valid_opt,  
+           #'valid/TP_opt': TP_valid_opt,   
+           #'valid/FP_opt': FP_valid_opt,   
+           #'valid/TN_opt': TN_valid_opt,   
+           #'valid/FN_opt': FN_valid_opt,  
            
-           'valid/opt_threshold_valid': opt_threshold_valid, 
+           #'valid/opt_threshold_valid': opt_threshold_valid, 
            
            'bias':bias
           }
